Conditional Execution
:::::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Condtional
   :maxdepth: 3

   boolean.rst
   logicalOperators.rst
   conditionalEx.rst
   altExecution.rst
   chained.rst
   nested.rst
   tryExcept.rst
   shortCircuit.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   MixedupCode.rst
   WriteCode.rst
   pogil.rst
